decollate
A high-performance, context-free collation library that provides blazing-fast locale-aware string comparison by deconstructing complex collation rules to their essential components.
This library is in active development.
Structs
- Collation
Options - Options for configuring collation behavior
- Collator
- Main collator structure that holds configuration and collation data
Enums
- Collation
Error - Error types for collation operations
- Collation
Strength - Defines the comparison strength level